@@ -33,12 +33,12 @@
 (defmacro no-warning (form)
   #+sbcl `(handler-bind
 	     ((style-warning #'muffle-warning)
-	      #+sbcl (sb-ext:compiler-note #'muffle-warning))
+              (sb-ext:compiler-note #'muffle-warning))
 	   ,form)
   #+clisp `(let ((custom:*suppress-check-redefinition* t)) ,form)
   #-(or sbcl clisp) `(progn ,form))
 
-($put '$wxmaxima `((mlist simp) 0 8 6) '$version)
+($put '$wxmaxima `((mlist simp) 0 8 7) '$version)
 
 (setf (get '$inchar 'assign) 'neverset)
 (setf (get '$outchar 'assign) 'neverset)
@@ -971,7 +971,7 @@
                      (list
 		      (format nil "<lbl>(~A)~A </lbl>"
 			      (stripdollar (maybe-invert-string-case (symbol-name (cadr x))))
-				  *wxxml-mratp*))
+                              *wxxml-mratp*))
 		     nil))
          r 'mparen 'mparen))
 
@@ -984,9 +984,9 @@
 
 (defun mydispla (x)
   (let ((*print-circle* nil)
-	    (*wxxml-mratp* (format nil "~{~a~}" (cdr (checkrat x)))))
-	(mapc #'princ
-		(wxxml x '("<mth>") '("</mth>") 'mparen 'mparen))))
+        (*wxxml-mratp* (format nil "~{~a~}" (cdr (checkrat x)))))
+    (mapc #'princ
+          (wxxml x '("<mth>") '("</mth>") 'mparen 'mparen))))
 
 (setf *alt-display2d* 'mydispla)
 
@@ -1195,7 +1195,7 @@
 	    ($first $wxplot_size)
 	    ($second $wxplot_size))))
 
-(defun $int_range (lo &optional hi)
+(defun $int_range (lo &optional hi (st 1))
   (unless (integerp lo)
     ($error "int_range: first argument is not an integer."))
   (unless (or (null hi) (integerp hi))
@@ -1203,7 +1203,7 @@
   (when (null hi)
     (setq hi lo)
     (setq lo 1))
-  (cons '(mlist simp) (loop for i from lo to hi collect i)))
+  (cons '(mlist simp) (loop :for i :from lo :to hi :by st :collect i)))
 
 (defun wxanimate (scene)
   (let* ((scene (cdr scene))
@@ -1232,7 +1232,8 @@
 			   ((mlist simp) $gnuplot_term $png)
 			   ((mlist simp) $gnuplot_out_file ,filename)))
 	(setq images (cons filename images))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
+    (when images
+      ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide"))))
   "")
 
 (defmspec $with_slider (scene)
@@ -1243,11 +1244,8 @@
 
 (defvar *windows-OS* (string= *autoconf-win32* "true"))
 
-(defun draw-transform (arg trans)
-  (declare (ignore trans))
-  arg)
-
 (defun wxanimate-draw (scene)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let* ((scene (cdr scene))
 	 (a (meval (car scene)))
 	 (a-range (meval (cadr scene)))
@@ -1259,20 +1257,23 @@
       (let* ((filename (wxplot-filename nil))
 	     (*windows-OS* t)
 	     (args (cons '($gr2d)
-			 (draw-transform
-			  (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
-				  args)
-			  '$draw2d_transform))))
+                         (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
+                                 args))))
 	(setq images (cons (format nil "~a.png" filename) images))
 	($apply '$draw
-		(append
-		 `((mlist simp)
-		   ((mequal simp) $terminal $png)
-		   ((mequal simp) $pic_width ,($first $wxplot_size))
-		   ((mequal simp) $pic_height ,($second $wxplot_size))
-		   ((mequal simp) $file_name ,filename))
-		 (list args)))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
+                (append
+                 `((mlist simp)
+                   ((mequal simp) $terminal $png)
+                   ((mequal simp) $file_name ,filename))
+                 (cond
+                   ((= ($get '$draw '$version) 1)
+                    `(((mequal simp) $pic_width ,($first $wxplot_size))
+                      ((mequal simp) $pic_height ,($second $wxplot_size))))
+                   (t
+                    `(((mequal simp) $dimensions ,$wxplot_size))))
+                 (list args)))))
+    (when images
+      ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide"))))
   "")
 
 (defmspec $wxanimate_draw (scene)
@@ -1282,6 +1283,7 @@
   (wxanimate-draw scene))
 
 (defun wxanimate-draw3d (scene)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let* ((scene (cdr scene))
 	 (a (meval (car scene)))
 	 (a-range (meval (cadr scene)))
@@ -1293,20 +1295,23 @@
       (let* ((filename (wxplot-filename nil))
 	     (*windows-OS* t)
 	     (args (cons '($gr3d)
-			 (draw-transform
 			  (mapcar #'(lambda (arg) (meval (maxima-substitute aval a arg)))
-				  args)
-			  '$draw3d_transform))))
+				  args))))
 	(setq images (cons (format nil "~a.png" filename) images))
 	($apply '$draw
-		(append
-		 `((mlist simp)
-		   ((mequal simp) $terminal $png)
-		   ((mequal simp) $pic_width ,($first $wxplot_size))
-		   ((mequal simp) $pic_height ,($second $wxplot_size))
-		   ((mequal simp) $file_name ,filename))
-		 (list args)))))
-    ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide")))
+                (append
+                 `((mlist simp)
+                   ((mequal simp) $terminal $png)
+                   ((mequal simp) $file_name ,filename))
+                 (cond
+                   ((= ($get '$draw '$version) 1)
+                    `(((mequal simp) $pic_width ,($first $wxplot_size))
+                      ((mequal simp) $pic_height ,($second $wxplot_size))))
+                   (t
+                    `(((mequal simp) $dimensions ,$wxplot_size))))
+                 (list args)))))
+    (when images
+      ($ldisp (list '(wxxmltag simp) (format nil "~{~a;~}" images) "slide"))))
   "")
 
 (defmspec $with_slider_draw3d (scene)
@@ -1354,37 +1359,42 @@
   "")
 
 
-(dolist (fun '($draw $draw2d $draw3d $set_draw_defaults))
-  (setf (get fun 'autoload) "draw"))
-
 (defun $wxdraw2d (&rest args)
   (apply #'$wxdraw
-	 (list (cons '($gr2d) (draw-transform args '$draw2d_transform)))))
+	 (list (cons '($gr2d) args))))
 
 (defun $wxdraw3d (&rest args)
   (apply #'$wxdraw
-	 (list (cons '($gr3d) (draw-transform args '$draw3d_transform)))))
+	 (list (cons '($gr3d) args))))
 
 (defvar $display_graphics t)
 
 (defun $wxdraw (&rest args)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let* ((filename (wxplot-filename nil))
 	 (*windows-OS* t)
 	 res)
     (setq res ($apply '$draw
-		     (append
-		      `((mlist simp)
-			((mequal simp) $terminal $png)
-			((mequal simp) $pic_width ,($first $wxplot_size))
-			((mequal simp) $pic_height ,($second $wxplot_size))
-			((mequal simp) $file_name ,filename))
-		      args)))
+                      (append
+                       `((mlist simp)
+                         ((mequal simp) $terminal $png)
+                         ((mequal simp) $file_name ,filename))
+                       (cond
+                         ((= ($get '$draw '$version) 1)
+                          `(((mequal simp) $pic_width ,($first $wxplot_size))
+                            ((mequal simp) $pic_height ,($second $wxplot_size))))
+                         (t
+                          `(((mequal simp) $dimensions ,$wxplot_size))))
+                       args)))
     (if $display_graphics
-	($ldisp `((wxxmltag simp) ,(format nil "~a.png" filename) "img"))
+	(progn
+          ($ldisp `((wxxmltag simp) ,(format nil "~a.png" filename) "img"))
+          (setq res ""))
 	(setf res `((wxxmltag simp) ,(format nil "~a.png" filename) "img")))
     res))
 
 (defmspec $wxdraw_list (args)
+  (unless ($get '$draw '$version) ($load "draw"))
   (let (($display_graphics nil))
     ($ldisp (cons '(mlist simp) (mapcar #'meval (cdr args)))))
   '$done)
